@@ -40,7 +40,12 @@ class BaseGenerator(object):
     update: bool = False
     base_dir: str = None
 
-    def __init__(self, app_config: object, force: bool=False, update: bool=False):
+    def __init__(
+        self,
+        app_config: object,
+        force: bool = False,
+        update: bool = False
+    ):
         self.app_config = app_config
         self.options = app_config.options
         self.update = update
@@ -50,7 +55,7 @@ class BaseGenerator(object):
 
         self.context = Context({
             'app_config': self.app_config,
-            'app_name': self.app_config.name, # This is singular app name.
+            'app_name': self.app_config.name,  # This is singular app name.
             'models': self.app_config.models_meta,
         })
 
@@ -60,7 +65,8 @@ class BaseGenerator(object):
     def generate_models(self):
         if self.update:
             if self.app_config.options.nested:
-                self._generate_by_group(group_name='models', init_view=MODEL_INIT)
+                self._generate_by_group(
+                    group_name='models', init_view=MODEL_INIT)
             else:
                 self.previous_content = self.read_previous_file('models.py')
                 self.context['previous_content'] = self.previous_content
@@ -69,7 +75,8 @@ class BaseGenerator(object):
         else:
             if self.app_config.options.nested:
                 # generate init view
-                self._generate_by_group(group_name='models', init_view=MODEL_INIT)
+                self._generate_by_group(
+                    group_name='models', init_view=MODEL_INIT)
             else:
                 self._generate_single_view(name='models')
 
@@ -190,7 +197,8 @@ class BaseGenerator(object):
 
     def models_content(self, model_meta=None):
         if model_meta is not None:
-            return self.get_grouping_content(model_meta=model_meta, view=MODEL_VIEW)
+            return self.get_grouping_content(
+                model_meta=model_meta, view=MODEL_VIEW)
         return self._view_template_content()
 
     def app_config_content(self):
@@ -263,7 +271,8 @@ class BaseGenerator(object):
 
         for model_meta in self.app_config.models_meta:
             if not (model_meta.existed is True and group_name == 'models'):
-                content = getattr(self, f'{group_name}_content')(model_meta=model_meta)
+                content = getattr(self, f'{group_name}_content')(
+                    model_meta=model_meta)
                 filename = f'{group_name}/{model_meta.verbose_name_plural}.py'
                 self._generate_file_template(filename, content)
 
@@ -322,7 +331,7 @@ class BaseGenerator(object):
         new_file.close()
         return True
 
-    def read_previous_file(self, filename: str, base_dir: str=None):
+    def read_previous_file(self, filename: str, base_dir: str = None):
         if base_dir is None:
             base_dir = self.base_dir
 
@@ -390,7 +399,8 @@ class AppConfigGenerator(BaseGenerator):
 class ApiGenerator(BaseGenerator):
 
     def __init__(self, app_config, force=False, update=False):
-        super(ApiGenerator, self).__init__(app_config, force=force,update=update)
+        super(ApiGenerator, self) \
+            .__init__(app_config, force=force, update=update)
 
         if update:
             print_out_override_message('apis', app_config=app_config)
@@ -416,7 +426,8 @@ class FactoryGenerator(BaseGenerator):
 class SerializerGenerator(BaseGenerator):
 
     def __init__(self, app_config, force=False, update=False):
-        super(SerializerGenerator, self).__init__(app_config, force, update=update)
+        super(SerializerGenerator, self) \
+            .__init__(app_config, force, update=update)
 
         if update:
             print_out_override_message('serializers', app_config=app_config)
@@ -438,6 +449,7 @@ class AdminGenerator(BaseGenerator):
         self.view_template = Template(ADMIN_VIEW)
         self.generate_admin()
 
+
 class FilterGenerator(BaseGenerator):
 
     def __init__(self, app_config, force=False, update=False):
@@ -466,7 +478,8 @@ class PermissionGenerator(BaseGenerator):
 class UnitTestGenerator(BaseGenerator):
 
     def __init__(self, app_config, force=False, update=False):
-        super(UnitTestGenerator, self).__init__(app_config, force, update=update)
+        super(UnitTestGenerator, self) \
+            .__init__(app_config, force, update=update)
 
         if update:
             print_out_override_message('tests', app_config=app_config)
@@ -482,6 +495,6 @@ class ApidocGenerator(BaseGenerator):
         super(ApidocGenerator, self).__init__(app_config, force)
 
         if self.app_config is not None \
-            and self.app_config.options.api_doc:
+                and self.app_config.options.api_doc:
             self.base_dir = os.path.join(self.base_dir, '../doc')
             self.generate_apidoc()
