@@ -31,10 +31,11 @@ ABERRANT_PLURAL_MAP = {
     'torpedo': 'torpedoes',
     'veto': 'vetoes',
     'woman': 'women',
-    }
+}
 
 VOWELS = set('aeiou')
 
+
 def pluralize(singular):
     """Return plural form of given lowercase singular word (English only). Based on
     ActiveState recipe http://code.activestate.com/recipes/413172/
@@ -75,13 +76,13 @@ def print_out_override_message(
 ):
     if component_name is None \
         or app_config is None \
-        or app_config.options is None:
+            or app_config.options is None:
         return
 
     app_name: str = app_config.name
 
-    if app_config.options.nested \
-        and component_name in ['apis', 'tests', 'factories', 'serializers']:
+    if app_config.options.nested and \
+            component_name in ['apis', 'tests', 'factories', 'serializers']:
         print(f'override - {app_name}/{component_name}/*.py')
     else:
         print(f'override - {app_name}/{component_name}.py')
