@@ -10,6 +10,9 @@ from {{ app_name }}.models import ({% for model in models %}
 # {{ model.object_name }}
 # =============================================================================
 class {{ model.object_name }}Filtering(BaseFiltering):
+    \"\"\"
+    {{ model.object_name }} Filtering
+    \"\"\"
 
     class Meta:
         model = {{ model.object_name }}
