@@ -11,7 +11,9 @@ from {{ app_name }}.models import ({% for model in models %}
 # {{ model.object_name }}Serializer
 # =============================================================================
 class {{ model.object_name }}Serializer(serializers.ModelSerializer):
-    # Serializer for {{ model.object_name }} model.
+    \"\"\"
+    Serializer for {{ model.object_name }} model.
+    \"\"\"
 
     class Meta:
         model = {{ model.object_name }}
@@ -27,7 +29,9 @@ from {{ app_name }}.models.{{ model_meta.verbose_name_plural }} import {{ model_
 # {{ model_meta.object_name }}Serializer
 # =============================================================================
 class {{ model_meta.object_name }}Serializer(serializers.ModelSerializer):
-    # Serializer for {{ model_meta.object_name }} model.
+    \"\"\"
+    Serializer for {{ model_meta.object_name }} model.
+    \"\"\"
 
     class Meta:
         model = {{ model_meta.object_name }}
